@@ -11,6 +11,8 @@ import time
 import requests
 from RainbowMonitoringSDK.exporters.Exporter import Exporter
 
+from RainbowMonitoringSDK.samplers.adam.main.AdaM import AdaM
+
 
 class IgniteExporter(Exporter):
     """
@@ -19,20 +21,53 @@ class IgniteExporter(Exporter):
 
     connection_timer = 5
     ignite_request_has_failed = True
+    adaptivity_samples = {}
+    sampling_periods = {}
 
-    def __init__(self, hostname, port, metric_repr=None):
-        self.hostname, self.port, self.metric_repr = hostname, port, metric_repr
+    def __init__(self, hostname, port, metric_repr=None, adaptivity={}):
+        self.hostname, self.port, self.metric_repr, self.adaptivity = hostname, port, metric_repr, adaptivity
+        if self.adaptivity is None:
+            self.adaptivity = {}
+        self.sampling_periods = {}
         Exporter.__init__(self, "IgniteExporter")
 
     def update(self, data: dict):
         res = []
+        all_metrics_count = 0
         for _, metrics in data.items():
             print(f"Metrics from {_} have {len(metrics)} datapoints")
+            all_metrics_count += len(metrics)
             for metric_name, metric in metrics.items():
-                metric_repr = self.__extract_metric_representation(metric)
-                res.append(metric_repr)
+                self.update_metric_list(metric, res)
+
+        print(f"From {all_metrics_count} metrics we disseminate {len(res)} datapoints")
         self.metric_repr = res
-        self.send_data(res)
+        if all_metrics_count>0:
+            self.send_data(res)
+
+    def update_metric_list(self, metric, res):
+        metric_repr = self.__extract_metric_representation(metric)
+        metric_id = metric_repr['metricID'] if metric_repr['metricID'] != "" else metric_repr['name']
+        if metric_id in self.adaptivity or 'all' in self.adaptivity:
+            if 'all' in self.adaptivity:
+                properties = self.adaptivity.get('all', {})
+            else:
+                properties = self.adaptivity.get(metric_id, {})
+            Tmin = properties.get('minimum_periodicity', 1)
+            Tmax = properties.get('maximum_periodicity', 1)
+            g = float(properties.get('confidence', 0.05))
+            _lambda = 1
+            if metric_id not in self.adaptivity_samples:
+                self.adaptivity_samples[metric_id] = AdaM(Tmin, Tmax, g, _lambda)
+            if metric_id not in self.sampling_periods:
+                self.sampling_periods[metric_id] = 1
+            self.adaptivity_samples[metric_id].update_sampling_period(metric)
+            if self.sampling_periods[metric_id] <= Tmin:
+                self.sampling_periods[metric_id] = self.adaptivity_samples[metric_id].get_sampling_period()
+                res.append(metric_repr)
+            self.sampling_periods[metric_id] -= 1
+        else:
+            res.append(metric_repr)
 
     def send_data(self, res):
 
@@ -46,11 +81,11 @@ class IgniteExporter(Exporter):
                 logging.info("Ignite server returns %s with the following response: %s" %
                              (response.status_code, response.text))
                 IgniteExporter.ignite_request_has_failed = False
-            except:
+            except Exception as ex:
                 IgniteExporter.ignite_request_has_failed = True
-                logging.error("Error at the API does not respond", exc_info=True)
+                logging.error(f"Error at the API does not respond {ex}", exc_info=True)
                 # wait for some seconds (< 5 min) to retry to search for ignite exporter
-                logging.error("Waiting %s seconds to retry to search for Ignite Exporter" % IgniteExporter.connection_timer)
+                logging.error(f"Waiting {IgniteExporter.connection_timer} seconds to retry to search for Ignite Exporter")
                 time.sleep(IgniteExporter.connection_timer)
                 # double the wait
                 if IgniteExporter.connection_timer < 300:
