@@ -12,7 +12,7 @@ class KafkaExporter(Exporter):
     """
     producer: KafkaProducer = None
 
-    def __init__(self, brokers: str, topic: str = "metrics"):
+    def __init__(self, brokers: str, topic: str = "metrics", **kwargs):
         self.topic = topic
         self.brokers = brokers
 
