@@ -8,7 +8,7 @@ class RestAPIExporter(Exporter):
     API extractor class. This extractor provides an API where other services can request it
     """
 
-    def __init__(self, port: int, path: str):
+    def __init__(self, port: int, path: str, **kwargs):
         self.port = port
         self.path = path
         self.data = {}
