@@ -1,4 +1,3 @@
-
 import docker
 from RainbowMonitoringSDK.probes.Probe import Probe
 from RainbowMonitoringSDK.probes.Metric import SimpleMetric
@@ -9,7 +8,7 @@ class DockerProbe(Probe):
                  periodicity, debug=False, _logging=False,
                  docker_client=None,
                  **kwargs):
-        Probe.__init__(self, "DockerProbe", periodicity,  debug, _logging)
+        Probe.__init__(self, "DockerProbe", periodicity,  debug, _logging, **kwargs)
         self.docker_client = docker.from_env() if docker_client is None else docker_client
         self.config = kwargs
 
@@ -33,20 +32,14 @@ class DockerProbe(Probe):
         for container in containers:
             curr_metrics = []
             attrs = container.attrs
-            attributes = container.attrs.get('Config', {})
+            config = container.attrs.get('Config', {})
             stats = container.stats(stream=False)
 
-            is_pod = attributes.get("Labels", {}).get("io.kubernetes.container.name") == "POD"
+            is_pod = config.get("Labels", {}).get("io.kubernetes.container.name") == "POD"
             
             if is_pod: continue
             container_id = attrs.get("Id")[:12]
-            pod_uid = attributes.get("Labels", {}).get("io.kubernetes.pod.uid")
-            pod_name = attributes.get("Labels", {}).get("io.kubernetes.pod.name")
-            container_name = attributes.get("Labels", {}).get("io.kubernetes.container.name")
-            pod_namespace = attributes.get("Labels", {}).get("io.kubernetes.pod.namespace")
-            prefix = f"CONTAINER_{container_id}"
-            if pod_uid:
-                prefix = f"CONTAINER_{pod_namespace}|{pod_name}|{pod_uid}|{container_name}|{container_id}|"
+            pod_name, pod_namespace, pod_uid, prefix = self.get_container_info(container_id, container.attrs)
             curr_metrics.append(self.get_cpu_ms(stats, prefix))
             curr_metrics.append(self.get_cpu_ptc(stats, prefix))
             curr_metrics.append(self.get_memory_usage(stats, prefix))
@@ -79,6 +72,18 @@ class DockerProbe(Probe):
             metrics.append(metric)
         return metrics
 
+    def get_container_info(self, container_id, attributes):
+        config = attributes.get('Config', {})
+        pod_uid = config.get("Labels", {}).get("io.kubernetes.pod.uid", "")
+        pod_name = config.get("Labels", {}).get("io.kubernetes.pod.name", "")
+        container_name = config.get("Labels", {}).get("io.kubernetes.container.name", "")
+        pod_namespace = config.get("Labels", {}).get("io.kubernetes.pod.namespace", "")
+        if not pod_uid:
+            container_name = attributes.get("Name")[1:]
+        prefix = f"CONTAINER_{pod_namespace}|{pod_name}|{pod_uid}|{container_name}|{container_id}|"
+
+        return pod_name, pod_namespace, pod_uid, prefix
+
     def update_pod_stats(self, curr_metric, pod_stats):
         pod_curr_metric = pod_stats.get(curr_metric.get_name(),
                                    SimpleMetric(curr_metric.get_name(), curr_metric.get_units(), curr_metric.get_desc(),
@@ -92,7 +97,7 @@ class DockerProbe(Probe):
         for i in stats:
             usage = stats[i]
             simple_metric = SimpleMetric(
-                f"{prefix}_{net}_{i}", i.split("_")[1], f"Network metric ({i}) of the container for {net} interface", minVal=0,
+                f"{prefix}{net}_{i}", i.split("_")[1], f"Network metric ({i}) of the container for {net} interface", minVal=0,
                                          higherIsBetter=False)
 
             simple_metric.set_val(usage)
@@ -106,7 +111,7 @@ class DockerProbe(Probe):
             usage = stats['memory_stats']['usage']
         except Exception:
             usage = 0
-        simple_metric = SimpleMetric(f"{prefix}_memory", "bytes", "Occupied memory of the container", minVal=0, higherIsBetter=False)
+        simple_metric = SimpleMetric(f"{prefix}memory", "bytes", "Occupied memory of the container", minVal=0, higherIsBetter=False)
 
         simple_metric.set_val(usage)
         simple_metric.set_timestamp(stats['read'])
@@ -120,7 +125,7 @@ class DockerProbe(Probe):
             percent = round(percentage, 5)
         except Exception:
             percent = 0
-        simple_metric = SimpleMetric(f"{prefix}_memory_ptc", "%", "Percentage memory of the container", minVal=0,
+        simple_metric = SimpleMetric(f"{prefix}memory_ptc", "%", "Percentage memory of the container", minVal=0,
                                      higherIsBetter=False)
         simple_metric.set_val(percent)
         simple_metric.set_timestamp(stats['read'])
@@ -131,7 +136,7 @@ class DockerProbe(Probe):
             total_cpu_usage = stats['cpu_stats']['cpu_usage']['total_usage']
         except Exception:
             total_cpu_usage = 0
-        simple_metric = SimpleMetric(f"{prefix}_cpu", "ms", "cpu runtime of the container", minVal=0,
+        simple_metric = SimpleMetric(f"{prefix}cpu", "ms", "cpu runtime of the container", minVal=0,
                                      higherIsBetter=False)
         simple_metric.set_val(total_cpu_usage)
         simple_metric.set_timestamp(stats['read'])
@@ -146,11 +151,11 @@ class DockerProbe(Probe):
             percent = round(percentage, 2)
         except Exception:
             percent = 0
-        simple_metric = SimpleMetric(f"{prefix}_cpu_ptc", "%", "cpu percent utilization of the container", minVal=0, higherIsBetter=False)
+        simple_metric = SimpleMetric(f"{prefix}cpu_ptc", "%", "cpu percent utilization of the container", minVal=0, higherIsBetter=False)
         simple_metric.set_val(percent)
         simple_metric.set_timestamp(stats['read'])
         return simple_metric
 
-    def get_metrics(self):
-        self.collect()
-        return Probe.get_metrics(self)
+    # def get_metrics(self):
+    #     self.collect()
+    #     return Probe.get_metrics(self)
