@@ -45,7 +45,6 @@ class NetDataProbe(Probe):
         }
     __NETDATA_URL_TEMPLATE = "http://%s:%s/api/v1/allmetrics"
 
-    __NETDATA_STARTED = 0
 
     def __init__(self,
                  periodicity,
@@ -82,13 +81,13 @@ class NetDataProbe(Probe):
         for regex in self.__REGEX_METRIC_NAME_FOR_DEMO:
             if re.search(regex, metric_name):
                 return self.__REGEX_METRIC_NAME_FOR_DEMO.get(regex)
-        return False
+        return metric_name
+        # return False
 
     def retrieve_metrics(self):
         res = []
         try:
             metrics = requests.get(self.url).text
-            self.__NETDATA_STARTED = 1
         except Exception as e:
             print("NetData is not working: ", e)
             return []
