@@ -14,10 +14,13 @@ class ThreadSafeDict(dict) :
     def __exit__(self, type, value, traceback) :
         self._lock.release()
 
+class ConverterException(Exception):
+    pass
+
 def time_to_seconds(input):
     if input.isnumeric(): return int(input)
     unit = input[-1].lower()
     if unit == 's': return int(input[:-1])
     if unit == 'm': return 60 * int(input[:-1])
     if unit == 'h': return 60 * 60 * int(input[:-1])
-    raise Exception("The time unit is not defined")
\ No newline at end of file
+    raise ConverterException("The time unit is not defined")
\ No newline at end of file
